import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:flutter_lingman/idemon_config.dart';
import 'package:get/get.dart';

class RequestInterceptor extends Interceptor {
  @override
  void onRequest(RequestOptions options, RequestInterceptorHandler handler) {
    Map<String, String> data = Get.find<IDemonConfig>().getHttpHeader();
    options.headers["Content-Type"] = "application/json";
    if (data.isNotEmpty) {
      options.headers.addAll(data);
    }

    return super.onRequest(options, handler);
  }

  @override
  void onError(DioError err, ErrorInterceptorHandler handler) {
    debugPrint("在错误之前进行拦截");

    switch (err.type) {
      case DioErrorType.connectTimeout:
        debugPrint("请求超时");
        break;
      case DioErrorType.sendTimeout:
        debugPrint("发送超时");
        break;
      case DioErrorType.receiveTimeout:
        debugPrint("响应超时");
        break;
      case DioErrorType.response:
        debugPrint("服务器繁忙");
        break;

      case DioErrorType.other:
        debugPrint("其他错误");
        break;
      case DioErrorType.cancel:
        debugPrint("取消请求");
        break;
    }
    super.onError(err, handler);
  }
}
